@@ -121,8 +121,7 @@ class Data:
     def __init__(self,
                  columns=['Qz / Aa^-1', 'RQz', 'sigma RQz, standard deviation',
                           'sigma Qz / Aa^-1, standard deviation'],
-                 n_qvectors=50, q_min=None, q_max=None, q_step=None,
-                 q_shape='log'):
+                 n_qvectors=50, q_step=None, q_shape='log'):
         self.column_1 = columns[0]
         self.column_2 = columns[1]
         self.column_3 = columns[2]
@@ -340,7 +339,7 @@ def i07reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/',
         print("-" * 10)
         print('Rebinning')
         print("-" * 10)
-        if the_boss.data.q_min is None:
+        if the_boss.data.q_step is None:
             refl.rebin(number_of_q_vectors=the_boss.data.n_qvectors)
         else:
             if the_boss.data.q_space == 'linear':
